/* SelfModifying linker script, for normal executables */
OUTPUT_FORMAT("elf32-c17")
OUTPUT_ARCH(c17)
ENTRY(_start)
SEARCH_DIR(.);
MEMORY
{
	iram		: ORIGIN = 0x0000,	LENGTH = 12K
	bootloader	: ORIGIN = 0x8000,	LENGTH = 8K
	fls_rom		: ORIGIN = 0xA000,	LENGTH = 4K
	indicator	: ORIGIN = 0xB000,	LENGTH = 4K
	program		: ORIGIN = 0xC000,	LENGTH = 112K
}
SECTIONS
{
	.bss (NOLOAD) :
	{
		PROVIDE (__START_bss = .) ;
		*(EXCLUDE_FILE (*fls17*RAM.o *fls17*ROM.o) .bss)
		*(.bss.*)
		*(COMMON)
		PROVIDE (__END_bss = .) ;
	}  > iram
	.vector :
	{
		PROVIDE (__START_vector = .) ;
		KEEP (*crt0.o(.rodata))
		PROVIDE (__END_vector = .) ;
	}  > bootloader
	.text :
	{
		PROVIDE (__START_text = .) ;
		*(.text.*)
		*(EXCLUDE_FILE (*fls17*RAM.o *fls17*ROM.o) .text)				/* Edit for self programming. */
		PROVIDE (_init_device = DEFINED (_crt0_init_device) ? _crt0_init_device : _crt0_init_dummy ) ;
		PROVIDE (_start_device = DEFINED (_crt0_start_device) ? _crt0_start_device : _crt0_init_dummy ) ;
		PROVIDE (_stop_device = DEFINED (_crt0_stop_device) ? _crt0_stop_device : _crt0_init_dummy ) ;
		PROVIDE (_init_section = DEFINED (_crt0_init_section) ? _crt0_init_section : _crt0_init_dummy ) ;
		PROVIDE (_init_lib = DEFINED (_crt0_init_lib) ? _crt0_init_lib : _crt0_init_dummy ) ;
		PROVIDE (_init_sys = DEFINED (_crt0_init_sys) ? _crt0_init_sys : _crt0_init_dummy ) ;
		PROVIDE (_start1 = DEFINED (_crt0_start1) ? _crt0_start1 : _crt0_init_dummy ) ;
		PROVIDE (_start = DEFINED (_crt0_start0) ? _crt0_start0 : _crt0_init_dummy ) ;
		PROVIDE (_exit = DEFINED (_crt0_exit) ? _crt0_exit : _crt0_init_dummy ) ;
		PROVIDE (__END_text = .) ;
	}  > bootloader
	.data :
	{
		PROVIDE (__START_data = .) ;
		*(EXCLUDE_FILE (*fls17*RAM.o *fls17*ROM.o) .data)
		*(.data.*)
		PROVIDE (__END_data = .) ;
	}  > iram AT > bootloader
	.rodata :
	{
		PROVIDE (__START_rodata = .) ;
		*(EXCLUDE_FILE (*crt0.o *fls17*RAM.o *indicator.o *flentry.o) .rodata)	/* Edit for self programming. */
		*(.rodata.*)
		PROVIDE (__END_rodata = .) ;
	}  > bootloader
	.flash_rom_text :
	{
		__START_flash_rom_text = . ;
		*flentry.o(.rodata);
		*fls17*ROM.o(.text);
		__END_flash_rom_text = . ;
	} > fls_rom
	
	PROVIDE (__START_data_lma = LOADADDR(.data));
	PROVIDE (__END_data_lma = LOADADDR(.data) + SIZEOF (.data));

	/* Add for self programming. */

	
	.flash_common_text :
	{
		__START_flash_common_text = . ;	
		*fls17*RAM.o(.text);
		__END_flash_common_text = . ; 
	} > iram AT > fls_rom

	.flash_common_rodata :
	{
		__START_flash_common_rodata = . ;
		*fls17*RAM.o(.data);
		*fls17*RAM.o(.rodata);
		__END_flash_common_rodata = . ; 
	} > iram AT > fls_rom
	
	
	__START_flash_common_text_lma = LOADADDR(.flash_common_text);
	__START_flash_common_rodata_lma = LOADADDR(.flash_common_rodata);
	
	.indicator :
	{
		*indicator.o(.rodata);
	} > indicator

	.program :
	{
		__START_program = . ;
	} > program
}
