/*******************************************************************************
 *
 * @file	boot.c
 * @brief	This is vector and interrupt program with C.
 *
 * @par		Copyright:
 * 			Copyright (C) SEIKO EPSON CORPORATION 2015-2016. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 15 Sep, 2015	1.00
 *				- First revision.
 *			- 31 Oct, 2015	1.10
 *				- Modify stack pointer definition.
 *			- 06 Jul, 2016	1.20
 *				- Delete stack pointer definition.
 *
 ******************************************************************************/
#include "crt0.h"
#include "init.h"

/* --- Non-Maskable Interrupts --- */
C17_INTERRUPT_HANDLER(_vector01_handler, intAddrErr);	// Address misaligned

/****************************************************************************
 * _init_device function.
 *
 * @brief	Initialize device module.
 ***************************************************************************/
void _init_device(void)
{
	/// Initialize module.
	setFlashcAccessCycle( FLASHCWAIT_RDWAIT_2 );

	return;
}

/****************************************************************************
 * _start_device function.
 *
 * @brief	Start device module.
 ***************************************************************************/
void _start_device(void){
	asm("di");						/// - Interrupt disable.
}

/****************************************************************************
 * intAddrErr function.
 *
 * @brief	Interrupt handler for "Address misaligned".
 ***************************************************************************/
void intAddrErr(void)
{
	/// Undecid processing.
	asm("halt");
}
