/****************************************************************************
 *
 * @file	clg.c
 * @brief	This is clg(osc) driver program file for S1C17W34/W35/W36 demonstration.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2015-2015. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 10 Sep, 2015	1.00
 *				- First revision.
 *
 ***************************************************************************/

#include "clg.h"

/****************************************************************************
 * startClgOSC3 function.
 *
 * @brief	Start OSC3.
 *
 * @param	freq	Oscillation frequency.  (CLG_OSC3_SEL...)
 ***************************************************************************/
void startClgOSC3f( unsigned short freq )
{
	/// It doesn't do at all when having already started.
	if ( CLGOSC_OSC3EN == 1 ) {
		return;
	}

	/// Disable write-protect.
	protectMisc( MSCPROT_PROTECT_OFF );

	/// Clear interrupt flag(CLGINTF.OSC3STAIF).
	CLGINTF					= 0x0004;

	/// Enable interrupt.(Please make the following effective when you use interrupt.)
	//CLGINTE_OSC3STAIE		= 1;

	CLGOSC_OSC3EN			= 0;	/// Stop OSC3.

	CLGOSC3	= 0x0004 | ( freq << 10 );	/// ----.**00.--##.-100  **=freq  The following substitutions.
	//CLGOSC3_OSC3MD			= 0;	/// Select an oscillator type of the OSC3(0 = Internal oscillator).
	//CLGOSC3_OSC3WT			= 4;	/// Set the oscillation stabilization waiting time(4 = 1,024 clocks).
	//CLGOSC3_OSC3FQ			= 3;	/// Set the oscillation frequency when the internal oscillator.

	asm("nop");
	asm("nop");
	asm("nop");

	/// Enable write-protect.
	protectMisc( MSCPROT_PROTECT_ON );

	CLGOSC_OSC3EN			= 1;		/// Start oscillation.

	while ( CLGINTF_OSC3STAIF == 0 ) {
		asm("nop");		// wait ...
	}
}

/****************************************************************************
 * stopClgIOSC function.
 *
 * @brief	Stop IOSC.
 ***************************************************************************/
void stopClgIOSC( void )
{
	CLGOSC_IOSCEN			= 0;	/// Stop IOSC.

	/// Disable interrupt.(Please make the following effective when you use interrupt.)
	///CLGINTE_IOSCSTAIE		= 0;

	/// Clear interrupt flag(CLGINTF.IOSCSTAIF and CLGINTF.IOSCTEDIF).
	CLGINTF					= 0x0011;
}

/****************************************************************************
 * switchClgSystemClockOSC3 function.
 *
 * @brief	The system clock set in OSC3.
 *
 * @retval	STATUS_OK	Success.
 * @retval	STATUS_NG	Failed.
 ***************************************************************************/
int switchClgSystemClockOSC3( void )
{
	/// When OSC3 doesn't start, nothing is done.
	if ( CLGOSC_OSC3EN == 0 ) {
		return STATUS_NG;
	}

	/// Disable write-protect.
	protectMisc( MSCPROT_PROTECT_OFF );

	/// Select the system clock source.
	CLGSCLK = (CLGSCLK & 0xffcc) | 0x0002;		/// Set system clock source(OSC3).
												/// Set division ratio of the clock source(1/1).

	/// Enable write-protect.
	protectMisc( MSCPROT_PROTECT_ON );

	return STATUS_OK;
}
