/* Default linker script, for normal executables */
OUTPUT_FORMAT("elf32-c17")
OUTPUT_ARCH(c17)
ENTRY(_start)
SEARCH_DIR(.);
MEMORY
{
	iram		: ORIGIN = 0x800,	LENGTH = 10K
	bootloader	: ORIGIN = 0x8000,	LENGTH = 16K
	irom 		: ORIGIN = 0xC000,	LENGTH = 112K
}
SECTIONS
{
	.bss (NOLOAD) :
	{
		PROVIDE (__START_bss = .) ;
		*(.bss)
		*(.bss.*)
		*(COMMON)
		PROVIDE (__END_bss = .) ;
	}  > iram
	.vector :
	{
		PROVIDE (__START_vector = .) ;
		KEEP (*crt0.o(.rodata))
		PROVIDE (__END_vector = .) ;
	}  > irom
	.text :
	{
		PROVIDE (__START_text = .) ;
		*(.text.*)
		*(.text)
		PROVIDE (_init_device = DEFINED (_crt0_init_device) ? _crt0_init_device : _crt0_init_dummy ) ;
		PROVIDE (_start_device = DEFINED (_crt0_start_device) ? _crt0_start_device : _crt0_init_dummy ) ;
		PROVIDE (_stop_device = DEFINED (_crt0_stop_device) ? _crt0_stop_device : _crt0_init_dummy ) ;
		PROVIDE (_init_section = DEFINED (_crt0_init_section) ? _crt0_init_section : _crt0_init_dummy ) ;
		PROVIDE (_init_lib = DEFINED (_crt0_init_lib) ? _crt0_init_lib : _crt0_init_dummy ) ;
		PROVIDE (_init_sys = DEFINED (_crt0_init_sys) ? _crt0_init_sys : _crt0_init_dummy ) ;
		PROVIDE (_start1 = DEFINED (_crt0_start1) ? _crt0_start1 : _crt0_init_dummy ) ;
		PROVIDE (_start = DEFINED (_crt0_start0) ? _crt0_start0 : _crt0_init_dummy ) ;
		PROVIDE (_exit = DEFINED (_crt0_exit) ? _crt0_exit : _crt0_init_dummy ) ;
		PROVIDE (__END_text = .) ;
	}  > irom
	.data :
	{
		PROVIDE (__START_data = .) ;
		*(.data)
		*(.data.*)
		PROVIDE (__END_data = .) ;
	}  > iram AT > irom
	.rodata :
	{
		PROVIDE (__START_rodata = .) ;
		*(EXCLUDE_FILE (*crt0.o ) .rodata)
		*(.rodata.*)
		PROVIDE (__END_rodata = .) ;
	}  > irom
	
	.bootloader :
	{
  		__START_bootloader = . ;
	} > bootloader
	
	PROVIDE (__START_data_lma = LOADADDR(.data));
	PROVIDE (__END_data_lma = LOADADDR(.data) + SIZEOF (.data));
	PROVIDE (__START_stack = 0x0007C0);
}
