/***************************************************************************
 *
 * @file	lcd32b_reg.h
 * @brief	Definition of the LCD Driver(LCD32B) Register.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2015-2015. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 07 Sep, 2015	1.00
 *				- First revision.
 *
 ************************************************************************* */
#ifndef	LCD32B_REG_H__
#define	LCD32B_REG_H__

#ifdef	__cplusplus
extern "C" {
#endif


/// LCD32B Clock Control Register.
typedef union LCD32CLK_REG_TAG{
	unsigned short			reg;
	struct LCD32CLK_REG_BIT_TAG{
		unsigned short		CLKSRC		: 2;	///< These bits select the clock source of the LCD32B.
		unsigned short		reserved_1	: 2;	///< Reserved.
		unsigned short		CLKDIV		: 3;	///< These bits select the division ratio of the LCD32B operating clock.
		unsigned short		reserved_2	: 1;	///< Reserved.
		unsigned short		DBRUN		: 1;	///< This bit sets whether the LCD32B operating clock is supplied in DEBUG mode or not.
		unsigned short		reserved_3	: 7;	///< Reserved.
	} bit;
	unsigned char 			byte_reg[2];
} LCD32CLK_REG;

/// LCD32B Control Register.
typedef union LCD32CTL_REG_TAG{
	unsigned short			reg;
	struct LCD32CTL_REG_BIT_TAG{
		unsigned short		MODEN		: 1;	///< This bit enables the LCD32B operations.
		unsigned short		LCDDIS		: 1;	///< This bit enables the discharge operations.
		unsigned short		reserved_1	:14;	///< Reserved.
	} bit;
	unsigned char 			byte_reg[2];
} LCD32CTL_REG;

/// LCD32B Timing Control Register 1.
typedef union LCD32TIM1_REG_TAG{
	unsigned short			reg;
	struct LCD32TIM1_REG_BIT_TAG{
		unsigned short		LDUTY		: 5;	///< These bits set the drive duty.
		unsigned short		COMLOC		: 1;	///< This bit select the COMx location.
		unsigned short		reserved_1	: 2;	///< Reserved.
		unsigned short		FRMCNT		: 5;	///< These bits set the frame frequency.
		unsigned short		reserved_2	: 3;	///< Reserved.
	} bit;
	unsigned char 			byte_reg[2];
} LCD32TIM1_REG;

/// LCD32B Timing Control Register 2.
typedef union LCD32TIM2_REG_TAG {
	unsigned short			reg;
	struct LCD32TIM2_REG_BIT_TAG {
		unsigned short		NLINE		: 5;	///< These bits enable the n-line inverse AC drive function and set the number of inverse lines.
		unsigned short		reserved_1	: 3;	///< Reserved.
		unsigned short		BSTC		: 2;	///< These bits select the booster clock frequency for the LCD voltage booster.
		unsigned short		reserved_2	: 6;	///< Reserved.
	} bit;
	unsigned char 			byte_reg[2];
} LCD32TIM2_REG;

/// LCD32B Power Control Register.
typedef union LCD32PWR_REG_TAG {
	unsigned short			reg;
	struct LCD32PWR_REG_BIT_TAG {
		unsigned short		VCEN		: 1;	///< This bit turns the LCD voltage regulator on and off.
		unsigned short		reserved_1	: 1;	///< Reserved.
		unsigned short		HVLD		: 1;	///< This bit sets the LCD voltage regulator into heavy load protection mode.
		unsigned short		BIASSEL		: 1;	///< This bit selects the LCD drive bias.
		unsigned short		BSTEN		: 1;	///< This bit turns the LCD voltage booster on and off.
		unsigned short		reserved_2	: 3;	///< Reserved.
		unsigned short		LC			: 4;	///< These bits set the LCD panel contrast.
		unsigned short		reserved_3	: 3;	///< Reserved.
		unsigned short		EXVCSEL		: 1;	///< This bit selects the LCD drive power supply mode (external voltage application mode or internal generation mode).
	} bit;
	unsigned char 			byte_reg[2];
} LCD32PWR_REG;

/// LCD32B Display Control Register.
typedef union LCD32DSP_REG_TAG {
	unsigned short			reg;
	struct LCD32DSP_REG_BIT_TAG {
		unsigned short		DSPC		: 2;	///< These bits control the LCD display on/off and select a display mode.
		unsigned short		DSPAR		: 1;	///< This bit switches the display area in the display data RAM.
		unsigned short		reserved_1	: 1;	///< Reserved.
		unsigned short		DSPREV		: 1;	///< This bit controls black/white inversion on the LCD display.
		unsigned short		COMREV		: 1;	///< This bit selects the common pin assignment direction.
		unsigned short		SEGREV		: 1;	///< This bit selects the segment pin assignment direction.
		unsigned short		reserved_2	: 9;	///< Reserved.
	} bit;
	unsigned char 			byte_reg[2];
} LCD32DSP_REG;

/// LCD32B COM Pin Control Register 0.
typedef union LCD32COMC0_REG_TAG {
	unsigned short			reg;
	struct LCD32COMC0_REG_BIT_TAG {
		unsigned short		COM0DEN		: 1;	///< This bit configure the partial drive of the COM0 pins.
		unsigned short		COM1DEN		: 1;	///< This bit configure the partial drive of the COM1 pins.
		unsigned short		COM2DEN		: 1;	///< This bit configure the partial drive of the COM2 pins.
		unsigned short		COM3DEN		: 1;	///< This bit configure the partial drive of the COM3 pins.
		unsigned short		COM4DEN		: 1;	///< This bit configure the partial drive of the COM4 pins.
		unsigned short		COM5DEN		: 1;	///< This bit configure the partial drive of the COM5 pins.
		unsigned short		COM6DEN		: 1;	///< This bit configure the partial drive of the COM6 pins.
		unsigned short		COM7DEN		: 1;	///< This bit configure the partial drive of the COM7 pins.
		unsigned short		COM8DEN		: 1;	///< This bit configure the partial drive of the COM8 pins.
		unsigned short		COM9DEN		: 1;	///< This bit configure the partial drive of the COM9 pins.
		unsigned short		COM10DEN	: 1;	///< This bit configure the partial drive of the COM10 pins.
		unsigned short		COM11DEN	: 1;	///< This bit configure the partial drive of the COM11 pins.
		unsigned short		COM12DEN	: 1;	///< This bit configure the partial drive of the COM12 pins.
		unsigned short		COM13DEN	: 1;	///< This bit configure the partial drive of the COM13 pins.
		unsigned short		COM14DEN	: 1;	///< This bit configure the partial drive of the COM14 pins.
		unsigned short		COM15DEN	: 1;	///< This bit configure the partial drive of the COM15 pins.
	} bit;
	unsigned char 			byte_reg[2];
} LCD32COMC0_REG;

/// LCD32B COM Pin Control Register 1.
typedef union LCD32COMC1_REG_TAG {
	unsigned short			reg;
	struct LCD32COMC1_REG_BIT_TAG {
		unsigned short		COM16DEN	: 1;	///< This bit configure the partial drive of the COM16 pins.
		unsigned short		COM17DEN	: 1;	///< This bit configure the partial drive of the COM17 pins.
		unsigned short		COM18DEN	: 1;	///< This bit configure the partial drive of the COM18 pins.
		unsigned short		COM19DEN	: 1;	///< This bit configure the partial drive of the COM19 pins.
		unsigned short		COM20DEN	: 1;	///< This bit configure the partial drive of the COM20 pins.
		unsigned short		COM21DEN	: 1;	///< This bit configure the partial drive of the COM21 pins.
		unsigned short		COM22DEN	: 1;	///< This bit configure the partial drive of the COM22 pins.
		unsigned short		COM23DEN	: 1;	///< This bit configure the partial drive of the COM23 pins.
		unsigned short		COM24DEN	: 1;	///< This bit configure the partial drive of the COM24 pins.
		unsigned short		COM25DEN	: 1;	///< This bit configure the partial drive of the COM25 pins.
		unsigned short		COM26DEN	: 1;	///< This bit configure the partial drive of the COM26 pins.
		unsigned short		COM27DEN	: 1;	///< This bit configure the partial drive of the COM27 pins.
		unsigned short		COM28DEN	: 1;	///< This bit configure the partial drive of the COM28 pins.
		unsigned short		COM29DEN	: 1;	///< This bit configure the partial drive of the COM29 pins.
		unsigned short		COM30DEN	: 1;	///< This bit configure the partial drive of the COM30 pins.
		unsigned short		COM31DEN	: 1;	///< This bit configure the partial drive of the COM31 pins.
	} bit;
	unsigned char 			byte_reg[2];
} LCD32COMC1_REG;



/// LCD32B Interrupt Flag Register.
typedef union LCD32INTF_REG_TAG {
	unsigned short			reg;
	struct LCD32INTF_REG_BIT_TAG {
		unsigned short		FRMIF		: 1;	///< This bit indicates the frame interrupt cause occurrence status.
		unsigned short		reserved_1	:15;	///< Reserved.
	} bit;
	unsigned char 			byte_reg[2];
} LCD32INTF_REG;

/// LCD32B Interrupt Enable Register.
typedef union LCD32INTE_REG_TAG {
	unsigned short			reg;
	struct LCD32INTE_REG_BIT_TAG {
		unsigned short		FRMIE		: 1;	///< This bit enables the frame interrupt.
		unsigned short		reserved_1	:15;	///< Reserved.
	} bit;
	unsigned char 			byte_reg[2];
} LCD32INTE_REG;


#ifdef __cplusplus
}
#endif

#endif	// LCD32B_REG_H__

